@@ -3,7 +3,7 @@
 import tkinter as tk
 
 print("""
-Merci d'utiliser la librairie entree du module pydiderot.\n
+Merci d'utiliser la librairie entree du module pydiderotlibs.\n
 N'hésitez pas à consulter la documentation en ligne:\n
 https://pydiderotlibs.rtfd.io/librairies/entree.html
 """)
@@ -20,9 +20,14 @@ def demander_texte(titre="Entrez un texte", message=None):
     Returns:
         La chaine de caractère (type ``str``) entrée par l'utilisateur.
     """
-    def _sauver_valeur(event=None):  # la fonction sauve la valeur dans value et ferme la fenetre
-        value.set(entree.get())
-        fenetre.destroy()
+
+    def _sauver_valeur(event=None):
+        """
+        Si entree est non vide, la fonction sauve sa valeur dans value et ferme la fenetre
+        """
+        if entree.get():
+            value.set(entree.get())
+            fenetre.destroy()
 
     fenetre = tk.Tk()
     fenetre.title(titre)
@@ -47,7 +52,6 @@ def demander_texte(titre="Entrez un texte", message=None):
 
     bouton = tk.Button(fenetre, text='Valider', command=_sauver_valeur)
     bouton.pack()
-
     fenetre.mainloop()
     return value.get()
 
@@ -66,6 +70,10 @@ def demander_reel(titre="Entrez un nombre réel"):
     message = None
     while True:
         texte = demander_texte(titre, message)
+        # Si texte est vide, l'utilisateur à fermé la fenetre
+        if not texte:
+            return
+        # Tente de convertir en float
         try:
             reel = float(texte)
         except ValueError:
@@ -90,6 +98,10 @@ def demander_entier(titre="Entrez un nombre entier"):
     message = None
     while True:
         texte = demander_texte(titre, message)
+        # si texte est vide, cela veut dire que l'utilisateur à fermé la fenêtre
+        if not texte:
+            return
+        # on essaye de convertir en int
         try:
             entier = int(texte)
         except ValueError:
