@@ -10,10 +10,10 @@ import sys
 import math
 import pygame
 from .couleurs import rgb
-
+from .touches_pygames import TOUCHES_PYGAMES
 # Un petit message invitant a lire la doc
 print("""
-Merci d'utiliser la librairie graphique du module pydiderot.\n
+Merci d'utiliser la librairie graphique du module pydiderotlibs.\n
 N'hésitez pas à consulter la documentation en ligne:\n
 https://pydiderotlibs.rtfd.io/librairies/graphique.html
 """)
@@ -25,12 +25,12 @@ _fenetre = None
 _autorefresh = True
 
 
-def creer_fenetre(largeur=200, hauteur=300, orientation_axe_ordonnees=False, titre="Fenetre graphique", autorefresh=True):
-    fenetre(largeur, hauteur, orientation_axe_ordonnees, titre)
+def creer_fenetre(largeur=600, hauteur=600, orientation_axe_ordonnees=False, titre="Fenetre graphique", autorefresh=True):
+    fenetre(largeur, hauteur, orientation_axe_ordonnees, titre, autorefresh)
 
 
 def window(largeur=600, hauteur=500, orientation_axe_ordonnees=False, titre="Fenetre graphique", autorefresh=True):
-    fenetre(largeur, hauteur, orientation_axe_ordonnees, titre)
+    fenetre(largeur, hauteur, orientation_axe_ordonnees, titre, autorefresh)
 
 
 def fenetre(
@@ -109,13 +109,6 @@ def demande_evenements():
 
     # Initialisation du dictionnaire de sortie
     evenements = {}
-    touches_speciales = {
-        'up': 'haut',
-        'down': 'bas',
-        'left': 'gauche',
-        'right': 'droite',
-        'space': 'espace'
-    }
 
     for event in pygame.event.get():
         # Gestion de la fermeture de la fenetre
@@ -128,13 +121,9 @@ def demande_evenements():
             evenements['clic'] = list(event.pos)
     # Gestion des touches. pygame.KeyDown ne va pas gérer plusieurs touches enfoncées
     # https://www.pygame.org/docs/ref/key.html#pygame.key.get_pressed
-    for index, enfoncee in enumerate(pygame.key.get_pressed()):
-        if enfoncee:
-            # On traduit les touches speciales
-            if pygame.key.name(index) in touches_speciales:
-                touche = touches_speciales[pygame.key.name(index)]
-            else:
-                touche = pygame.key.name(index)
+    touches = pygame.key.get_pressed()
+    for touche, k_touche in TOUCHES_PYGAMES.items():
+        if touches[getattr(pygame, k_touche)]:
             evenements[touche] = None
 
     return evenements
@@ -156,11 +145,11 @@ def erase(couleur='blanc'):
     efface(couleur)
 
 
-def trace_cercle(x, y, couleur='bleu', rayon=50, epaisseur=0):
+def trace_cercle(x, y, couleur='bleu', rayon=25, epaisseur=0):
     cercle(x, y, couleur, rayon, epaisseur)
 
 
-def circle(x, y, couleur='bleu', rayon=50, epaisseur=0):
+def circle(x, y, couleur='bleu', rayon=25, epaisseur=0):
     cercle(x, y, couleur, rayon, epaisseur)
 
 
@@ -189,7 +178,7 @@ def trace_cercle_aleatoire(couleur='bleu', rayon=5, epaisseur=0):
 
 def random_circle(couleur='bleu', rayon=5, epaisseur=0):
     cercle_aleatoire(couleur, rayon, epaisseur)
-    
+
 def randcircle(couleur='bleu', rayon=5, epaisseur=0):
     cercle_aleatoire(couleur, rayon, epaisseur)
 
