@@ -10,40 +10,84 @@ Licence CECILL http://www.cecill.info/
 from math import floor, log
 from .chaines import fich2chaine, chaine2fich
 
-def CSV2liste(num, fichier='optionnel'):
+
+def CSV_ligne(num,fichier='optionnel'):
     """
-    Retourne une liste correspondant à la colonne ou la ligne nom du fichier ``fichier``.
+    Retourne une liste de nombres (float) correspondant à la ligne du fichier ``fichier``.
 
     Si fichier n'est pas précisé, ouvre une boite de dialogue pour le choisir
     Le fichier ne doit contenir que des nombres et le séparateur doit être ``;``
 
     Arguments:
-        num (str ou int): Un numéro de ligne ou un nom de colonne (``A`` à ``Z`` ).
+        num (int): Un numéro de ligne.
         fichier (file,optionnel): Le nom complet (avec le chemin) d'un fichier contenant des nombres.
     """
     ch = fich2chaine(fichier)
-    if isinstance(num, int):
-        L = ch.split("\n")
-        if len(L) >= num:
-            R = []
-            for n in L[num - 1].split(";"):
-                try:
-                    R.append(eval(n))
-                except BaseException:
-                    raise Exception("Problème lors de l'importation")
-            return R
-    if isinstance(num, str):
-        num = num.upper()
-        c = ord(num) - ord('A')
-        R = []
-        for m1 in ch.split("\n"):
-            m2 = m1.split(";")
-            if len(m2) > c and m2[c] != '':
-                try:
-                    R.append(eval(m2[c].replace(' ', '').replace(',', '.')))
-                except BaseException:
-                    raise Exception("Problème lors de l'importation")
-        return R
+    L = ch.split("\n") # on separe les lignes en une liste
+    ligne = []
+    for i in L[num-1].split(";"):
+        if isinstance(i,str):
+            ligne.append(float(i.replace(",","."))) #gestion de la virgule avec un tableau de nombres en convention française
+        else:
+            ligne.append(float(i))
+    return(ligne)
+
+def CSV_colonne(num,fichier='optionnel'):
+    """
+    Retourne une liste de nombres (float) correspondant à la colonne du fichier ``fichier``.
+
+    Si fichier n'est pas précisé, ouvre une boite de dialogue pour le choisir
+    Le fichier ne doit contenir que des nombres et le séparateur doit être ``;``
+
+    Arguments:
+        num (int): Un numéro de colonne.
+        fichier (file,optionnel): Le nom complet (avec le chemin) d'un fichier contenant des nombres.
+    """
+    ch = fich2chaine(fichier)
+    colonne = []
+    for i in ch.split("\n"): #on parcourt les lignes
+        contenu=i.split(';')[num-1] #dans chaque ligne on récupère le contenu de la bonne colonne
+        if isinstance(contenu,str):
+            colonne.append(float(contenu.replace(",","."))) #gestion de la virgule avec un tableau de nombres en convention française
+        else:
+            colonne.append(float(contenu))
+    return(colonne)
+
+# Obsolète
+# def CSV2liste(num, fichier='optionnel'):
+#     """
+#     Retourne une liste correspondant à la colonne ou la ligne nom du fichier ``fichier``.
+#
+#     Si fichier n'est pas précisé, ouvre une boite de dialogue pour le choisir
+#     Le fichier ne doit contenir que des nombres et le séparateur doit être ``;``
+#
+#     Arguments:
+#         num (str ou int): Un numéro de ligne ou un nom de colonne (``A`` à ``Z`` ).
+#         fichier (file,optionnel): Le nom complet (avec le chemin) d'un fichier contenant des nombres.
+#     """
+#     ch = fich2chaine(fichier)
+#     if isinstance(num, int):
+#         L = ch.split("\n")
+#         if len(L) >= num:
+#             R = []
+#             for n in L[num - 1].split(";"):
+#                 try:
+#                     R.append(eval(n))
+#                 except BaseException:
+#                     raise Exception("Problème lors de l'importation")
+#             return R
+#     if isinstance(num, str):
+#         num = num.upper()
+#         c = ord(num) - ord('A')
+#         R = []
+#         for m1 in ch.split("\n"):
+#             m2 = m1.split(";")
+#             if len(m2) > c and m2[c] != '':
+#                 try:
+#                     R.append(eval(m2[c].replace(' ', '').replace(',', '.')))
+#                 except BaseException:
+#                     raise Exception("Problème lors de l'importation")
+#         return R
 
 
 def liste2CSV(L, fichier='optionnel'):
@@ -61,10 +105,6 @@ def liste2CSV(L, fichier='optionnel'):
     chaine2fich("\n".join(L), fichier)
 
 
-liste2CSV([1, 'a', 3, 'bonjour', 10, 'aurevoir'],
-          fichier='TableurPourTest2.csv')
-
-
 def trier(liste1, liste2=[]):
     """
     Retourne `liste1` triée.
