@@ -10,7 +10,7 @@ from .couleurs import rgb, rgb2hex
 
 # Un petit message invitant a lire la doc
 print("""
-Merci d'utiliser la librairie repere du module pydiderot.\n
+Merci d'utiliser la librairie repere du module pydiderotlibs.\n
 N'hésitez pas à consulter la documentation en ligne:\n
 https://pydiderotlibs.rtfd.io/librairies/repere.html
 """)
@@ -321,8 +321,7 @@ class _FenetreGraphique(Canvas):
 
 def trace_point(x, y, couleur='noir', taille=1, forme='rond'):
     point(x, y, couleur, taille, forme)
-
-
+    
 def point(x, y, couleur='noir', taille=1, forme='rond'):
     """Ajoute un point dans la fenetre graphique aux coordonees ``(x, y)``.
 
@@ -364,6 +363,24 @@ def point(x, y, couleur='noir', taille=1, forme='rond'):
     tab[6] = forme
     _fenetre.objets.append(tab)
 
+def cercle(x, y, couleur='noir', taille=5):
+    """Trace un disque dont le centre a pour coordonnées ``(x, y)`` et dont le rayon est 2 fois ``taille`` (en pixels).
+    
+    Alias: ``trace_cercle()``, ``circle()``
+    
+    Arguments:
+        x,y (float): Coordonnées du centre.
+        couleur (`couleur <#couleurs>`_, optionnel): Couleur du disque (``noir`` par défaut).
+        taille (int, optionl): demi rayon (``2`` par défaut).
+        """
+    point(x, y, couleur, taille, 'rond')
+
+def circle(x, y, couleur='noir', taille=5):
+    point(x, y, couleur, taille, 'rond')
+
+def trace_cercle(x, y, couleur='noir', taille=5):
+    point(x, y, couleur, taille, 'rond')
+
 
 def trace_texte(x, y, message, couleur='noir'):
     texte(x, y, message, couleur)
@@ -374,7 +391,7 @@ def text(x, y, message, couleur='noir'):
 
 
 def texte(x, y, message, couleur='noir'):
-    """Trace un texte dans la fenêtre graphique au coordonées ``x, y``.
+    """Trace un texte dans la fenêtre graphique au coordonnées ``x, y``.
 
     Alias : 'trace_texte()' et 'text()'
 
@@ -403,12 +420,12 @@ def trace_segment(x1, y1, x2, y2, couleur='noir', taille=2):
 
 
 def segment(x1, y1, x2, y2, couleur='noir', taille=2):
-    """Trace un segment entre les points de coordonées ``(x1, y1)`` et ``(x2, y2)``.
+    """Trace un segment entre les points de coordonnées ``(x1, y1)`` et ``(x2, y2)``.
 
     Alias: ``trace_segment()``
 
     Arguments:
-        x1,y1,x2,y2 (float): Coordonées des extrémités du segment.
+        x1,y1,x2,y2 (float): Coordonnées des extrémités du segment.
         couleur (`couleur <#couleurs>`_, optionnel): Couleur du segment (``noir`` par défaut).
         taille (int, optionl): Epaisseur du segment (``2`` par défaut).
         """
@@ -503,3 +520,45 @@ def fenetre(xmin=-10, xmax=10, ymin=-10, ymax=10, fond='blanc',
     global _fenetre
     _fenetre = graph
     return graph
+
+def courbe(valeurs= [(1,1),(2,2)], couleur="noir", type="courbe", taille=2, forme="rond"):
+    """Crée automatiquement une courbe en fonction des points donnés.
+
+    Arguments:
+        valeurs (list): Les points par lesquelles passe la courbe. La valeur par défaut est ``[(1,1), (2,2)]``.
+        couleur (`couleur <#couleurs>`_, optionnel): Couleur des cotés du rectangle (``noir`` par défaut).
+        type (str, optionnel): Le type de courbe à creer (``double``, ``courbe`` ou ``points``)
+        taile (int, optionel): La taille de la courbe (``2``par default)
+        forme (str, requis pour `points`): La forme des points (``rond`` par défault)
+    """
+
+    if type == "courbe":
+        empl = 0
+        # empl est l'emplacement de la valeur dans la liste "valeurs" 
+        for x, y in valeurs:
+            if empl != 0:
+                old_x, old_y = valeurs[empl-1]
+                # va chercher le X et le Y de l'emplacement N-1 pour faire un trait de N-1 vers N
+                segment(x, y, old_x, old_y, couleur=couleur, taille=taille)
+            empl += 1
+
+    elif type == "points":
+        for x, y in valeurs:
+             point(x, y, couleur=couleur, taille=taille, forme=forme)
+                
+
+    elif type == "double":
+        empl = 0
+        # empl est l'emplacement de la valeur dans la liste "valeurs" 
+        for x, y in valeurs:
+            point(x, y, couleur=couleur, taille=taille, forme=forme)
+            if empl != 0:
+                old_x, old_y = valeurs[empl-1]
+                # va chercher le X et le Y de l'emplacement N-1 pour faire un trait de N-1 vers N
+                segment(x, y, old_x, old_y, couleur=couleur, taille=taille)
+            empl += 1
+
+    else:
+        print("Type de courbe inconnu :(")
+
+            
