@@ -12,9 +12,14 @@ from .lycee import *
 import types
 import pydiderotlibs.repere as repere
 import pydiderotlibs.graphique as graphique
+from .nmea import *
 
 from .couleurs import _couleurs, rgb, rgb2hex
 
+"""
+La fonction test_listes doit être appelée dans un répertoire de travail du dépôt githib qui contient le sous dossier exemples.
+Cette fonction demande des noms de fichiers qui sont absents du dépôt pip. L'appeler en dehors du dossier github crée des erreurs.
+"""
 
 def test_lycee():
     """
@@ -26,7 +31,7 @@ def test_lycee():
     print('pgcd(-4,12) = ', pgcd(-4, 12))
     print('reste(15,4) = ', reste(15, 4))
     print('quotient(15,4) = ', quotient(15, 4))
-    
+
     # fonctions usuelles
     print('4**1/2 = ', puissance(4, 1 / 2))
     print('2**-2 = ', puissance(2, -2))
@@ -58,13 +63,13 @@ def test_listes():
     print('\n Les fonctions sur les listes à partir de fichier')
 
     print('On doit avoir une liste de 0 à 9 : ',
-          CSV2liste('A', 'TableurPourTest.csv'))
+          CSV_colonne(1, 'exemples/TableurPourTest.csv'))
     print('On doit avoir une liste de 10 en 10 : ',
-          CSV2liste(1, 'TableurPourTest.csv'))
+          CSV_ligne(1, 'exemples/TableurPourTest.csv'))
 
     liste2CSV([1, 'a', 3, 'bonjour', 10, 'aurevoir'],
-              fichier='TableurPourTest2.csv')
-    print('Votre répertoire courant doit contenir un fichier TableurPourTest2.csv')
+              fichier='exemples/TableurPourTest2.csv')
+    print('Votre répertoire courant/exemples doit contenir un fichier TableurPourTest2.csv')
 
     x = [[1, 2, 'a'], [3, 4, 'b'], [5, 6, 'c'], [7, 8, 'd']]
     print(x)
@@ -90,8 +95,8 @@ def test_stats_proba():
 
     print("Un nombre au hasard entre -5 et 5 avec la loi uniforme : ",
           tirage_uniforme(-5, 5))
-
-    print(range(0, 11))
+    contenu=range(0,11)
+    print("une liste pour tester : ", contenu)
     print("Un nombre au hasard dans la liste précédente : ", choix(contenu))
 
     print("Renvoie au hasard un décimal de l'intervalle [0 , 1[ : ", alea())
@@ -228,9 +233,32 @@ def test_couleurs():
 
     root.mainloop()
 
+def test_nmea():
+    """
+    Teste le module nmea
+    (pour la SNT, chapitre sur le GPS.)
+    Remarque : le fichier testnmeatools.txt se trouve dans pydiderotlibs/exemples
+    """
+    vitesses=nmea_timedata('speed','exemples/testnmeatools.txt')
+    repere.window()
+    max=0
+    for x,y in vitesses:
+        repere.point(x,y,'red')
+        if y>max:
+            max=y
+    print("voici la vitesse maximale dans le fichier testnmeatools.txt : "+max)
+    
+    msg = pynmeagps.NMEAReader.parse("$GPGGA,122623.000,4325.8430,N,00523.6647,E,1,7,1.32,232.1,M,49.2,M,,*58")
+    #msg = pynmeagps.NMEAReader.parse("$GPRMC,122623.000,A,4325.8430,N,00523.6647,E,39.821,290.36,261219,,,A*60")
+    print("fonction mk_dict : ")
+    print(mk_dict(msg))
+    print("fonction mk_list : ")
+    print(mk_list(msg,datetime.datetime.now()))
+    nmea2csv()
 
 print("\n" * 10)
 message = "Vous pouvez tester les différents modules avec les fonctions suivantes:\n"
 fonctions = [f + "()" for f in dir() if f.startswith("test")]
 message += "\n".join(fonctions)
+message += "La fonction test_listes doit être appelée dans un répertoire de travail du dépôt githib qui contient le sous dossier exemples. Cette fonction demande des noms de fichiers qui sont absents du dépôt pip. L'appeler en dehors du dossier github crée des erreurs."
 print(message)
